| b2ktoC14 | R Documentation |
Given a b2k age (years before AD 2000, popular in the ice core community), the calibration curve (default cc=1) is interpolated and the corresponding 14C age and error are returned.
b2ktoC14(
x,
cc = 1,
postbomb = FALSE,
glue = 0,
rule = 1,
cc.dir = NULL,
thiscurve = NULL,
roundby = Inf
)
x |
The b2k year. |
cc |
calibration curve for C14 (see |
postbomb |
Whether or not to use a postbomb curve (see |
glue |
Glue postbomb and prebomb curves together. Defaults to 0 (none), can be 1 (IntCal20 + NH1), 2 (IntCal20 + NH2), 3 (IntCal20 + NH3), 4 (SHCal20 + SH1-2) or 5 (SHCal20 + SH3). Note that this will override the value of cc. Can also be used to glue other pre-bomb and post-bomb curves, e.g., |
rule |
How should R's approx function deal with extrapolation. If |
cc.dir |
Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., |
thiscurve |
As an alternative to providing cc and/or postbomb, the data of a specific curve can be provided (3 columns: cal BP, C14 age, error). |
roundby |
Amount of decimals required for the output. Defaults to |
Interpolation is used, and values outside the calibration curve are given as NA. For ages younger than 50 b2k, a postbomb curve will have to be provided.
The calibration-curve 14C year belonging to the entered b2k age
Maarten Blaauw
b2ktoC14(100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.