Calculate the calibrated distribution of a radiocarbon date.
caldist(
y,
er,
cc = 1,
postbomb = FALSE,
bombalert = TRUE,
glue = 0,
deltaR = 0,
deltaSTD = 0,
is.F = FALSE,
is.pMC = FALSE,
as.F = TRUE,
thiscurve = NULL,
yrsteps = FALSE,
cc.resample = FALSE,
pb.steps = 0.05,
cc0.res = 5000,
threshold = 0.001,
normal = TRUE,
t.a = 3,
t.b = 4,
normalise = TRUE,
BCAD = FALSE,
rule = 1,
cc.dir = NULL,
col.names = NULL
)The probability distribution(s) as two columns: cal BP ages and their associated probabilities
Uncalibrated radiocarbon age
Lab error of the radiocarbon age
Calibration curve to use. Defaults to IntCal20 (cc=1), can be Marine20 (cc=2), SHCal20 (cc=3), or if postbomb=TRUE, NH1 (cc=1), NH2 (cc=2), NH3 (cc=3), SH1-2 (cc=4) or SH3 (cc=5).
Whether or not to use a postbomb curve. Required for negative radiocarbon ages.
Stop if a date is overly close to the younger limit of the IntCal curve. Defaults to bombalert=TRUE. This error can be avoided by either providing a postbomb curve (e.g., postbomb=1) or typing bombalert=FALSE (in this case, part of the date will be truncated).
Glue postbomb and prebomb curves together. Defaults to 0 (none), can be 1 (IntCal20 + NH1), 2 (IntCal20 + NH2), 3 (IntCal20 + NH3), 4 (SHCal20 + SH1-2) or 5 (SHCal20 + SH3). Note that this will override the value of cc. Can also be used to glue other pre-bomb and post-bomb curves, e.g., glue="NH1_monthly".
Age offset (e.g. for marine samples). This assumes that the radiocarbon age is provided as 14C BP (not F14C or pMC).
Uncertainty of the age offset (1 standard deviation).
Set this to TRUE if the provided age and error are in the F14C timescale.
Set this to TRUE if the provided age and error are in the pMC timescale.
Whether or not to calculate ages in the F14C timescale. Defaults to as.F=TRUE, so not using the C14 timescale (will be more accurate especially for dates with larger errors, e.g., older ones).
As an alternative to providing cc and/or postbomb/glue, the data of a specific curve can be provided (3 columns: cal BP, C14 age, error).
Steps to use for interpolation. Defaults to the cal BP steps in the calibration curve
The IntCal20 curves have different densities (every year between 0 and 5 kcal BP, then every 5 yr up to 15 kcal BP, then every 10 yr up to 25 kcal BP, and then every 20 yr up to 55 kcal BP). If calibrated ages span these density ranges, their drawn heights can differ, as can their total areas (which should ideally all sum to the same size). To account for this, resample to a constant time-span, using, e.g., cc.resample=5 for 5-yr timespans.
Yearly steps for postbomb curves. Defaults to 20 steps per year, pb.steps=0.05.
Length of 'curve' when cc=0 (no calibration curve). Defaults to 5000, in order to provide enough points for detailed distributions.
Report only values above a threshold. Defaults to threshold=1e-6.
Use the normal distribution to calibrate dates (default TRUE). The alternative is to use the t model (Christen and Perez 2016).
Value a of the t distribution (defaults to 3).
Value b of the t distribution (defaults to 4).
Sum the entire calibrated distribution to 1. Defaults to normalise=TRUE.
Which calendar scale to use. Defaults to cal BP, BCAD=FALSE.
Which extrapolation rule to use. Defaults to rule=1 which returns NAs.
Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., cc.dir="curves".
Names for the output columns. Defaults to calBP/BCAD and probs, respectively (depending on the value of BCAD).
calib <- caldist(130,10, bombalert=FALSE)
plot(calib, type="l")
postbomb <- caldist(-3030, 20, postbomb=1, BCAD=TRUE)
Run the code above in your browser using DataLab