| calib.t | R Documentation |
Visualise how a date calibrates using the t distribution and the normal distribution.
calib.t(
y = 2450,
er = 50,
t.a = 3,
t.b = 4,
cc = 1,
postbomb = FALSE,
glue = 0,
deltaR = 0,
deltaSTD = 0,
as.F = FALSE,
is.F = FALSE,
BCAD = FALSE,
zero = FALSE,
cal.rev = TRUE,
cc.dir = c(),
normal.col = "red",
normal.lwd = 1.5,
t.col = rgb(0, 0, 0, 0.25),
t.border = rgb(0, 0, 0, 0, 0.25),
xlim = c(),
ylim = c()
)
y |
The reported mean of the date. |
er |
The reported error of the date. |
t.a |
Value for the t parameter |
t.b |
Value for the t parameter |
cc |
calibration curve for the radiocarbon date(s) (see the |
postbomb |
Which postbomb curve to use for negative 14C dates. |
glue |
Glue postbomb and prebomb curves together. Defaults to 0 (none), can be 1 (IntCal20 + NH1), 2 (IntCal20 + NH2), 3 (IntCal20 + NH3), 4 (SHCal20 + SH1-2) or 5 (SHCal20 + SH3). Note that this will override the value of cc. |
deltaR |
Age offset (e.g. for marine samples). |
deltaSTD |
Uncertainty of the age offset (1 standard deviation). |
as.F |
Whether or not to calculate ages in the F14C timescale. Defaults to |
is.F |
Use this if the provided date is in the F14C timescale. |
BCAD |
Which calendar scale to use. Defaults to cal BP, |
zero |
Whether or not zero BC/AD should be included if using BCAD=TRUE. Defaults to |
cal.rev |
Reverse the calendar age axis. Defaults to TRUE |
cc.dir |
Directory where the calibration curves for C14 dates |
normal.col |
Colour of the normal curve |
normal.lwd |
Line width of the normal curve |
t.col |
Colour of the t histogram |
t.border |
Colour of the border of the t histogram |
xlim |
x axis limits |
ylim |
y axis limits |
Radiocarbon and other dates are usually modelled using the normal distribution (red curve). The t approach (grey distribution) however allows for wider tails and thus tends to better accommodate outlying dates. This distribution requires two parameters, called 'a' and 'b'.
Maarten Blaauw
calib.t()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.