fromto: translate between timescales

View source: R/timescales.R

fromtoR Documentation

translate between timescales

Description

translate between timescales

Usage

fromto(
  x,
  from = "calBP",
  cc = 1,
  postbomb = 0,
  cc.dir = NULL,
  thiscurve = NULL,
  zero = FALSE,
  width = c(),
  digits = 0,
  C14.col = rgb(0, 0, 1, 0.5),
  Delta14C.col = rgb(0, 0.4, 0, 0.4),
  ka = FALSE,
  cal.rev = TRUE,
  legend.size = 0.7
)

Arguments

x

The value to be translated into other timescales

from

The timescales of the entered value. Can be "calBP" for cal BP, "BCAD" for BC/AD, "C14" for C14 BP, "F14C" for F14C, or "pMC" for pMC. Delta14C cannot be entered as a value (you could enter the corresponding cal BP or BC/AD ages instead).

cc

calibration curve for C14 (see caldist()).

postbomb

Whether or not to use a postbomb curve (see caldist()).

cc.dir

Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., cc.dir="curves".

thiscurve

As an alternative to providing cc and/or postbomb, the data of a specific curve can be provided (3 columns: cal BP, C14 age, error).

zero

Whether or not zero BC/AD should be included. Defaults to not included, i.e., FALSE.

width

Width of the righthand plot. Calculated automatically by default (older ages get wider windows).

digits

Rounding of the reported values. Defaults to 0 digits.

C14.col

Colour of the 14C calibration curve. Defaults to semi-transparent blue, C14.col=rgb(0,0,1,.5).

Delta14C.col

Colour of the Delta14C curve. Defaults to semi-transparent green, Delta14C.col=rgb(0,.4,0,.4).

ka

Whether to use years or ka (thousands of years). Defaults to ka=FALSE.

cal.rev

Reverse the age axis (right panel). Defaults to TRUE.

legend.size

Size of the font of the legend. Defaults to 0.7 of R's standard size.

Details

Upon entering a value and its timescale, this function will find the corresponding values in the other timescales. Note that uncertainties are *not* taken into account, and especially going from C14 BP to cal BP and BC/AD ignores many calibration-related uncertainties. Delta14C values are only reported for entered values on the cal BP or BC/AD scale.

Value

A plot and output showing the translations into the different timescales.

Examples

  fromto(0, "BCAD")
  fromto(2450, "C14")

rice documentation built on Aug. 19, 2026, 5:07 p.m.