- calib
The calibrated distribution, as returned from caldist(). Alternatively this can be multiple values (e.g., rnorm(1e3, 2450,50)), from which the hpd ranges will be returned.
- prob
Probability range which should be calculated. Default prob=0.95.
- return.raw
The raw data to calculate hpds can be returned, e.g. to draw polygons of the calibrated distributions. Defaults to return.raw=FALSE.
- BCAD
Which calendar scale to use. Defaults to cal BP, BCAD=FALSE.
- ka
Whether to report results in years (default) or as ka
- age.round
Rounding for ages. Defaults to 0 decimals.
- prob.round
Rounding for reported probabilities. Defaults to 1 decimal.
- every
Yearly precision (defaults to 0.1, as a compromise between speed and accuracy).
- bins
The number of bins required. Any distribution with fewer bins gets recalculated using 100 narrower bins.
- add.zeros
Pad the distribution with zeros at both extremes. Can be useful for distributions with 'open endings'. Defaults to FALSE