- x
The cal BP year.
- y
The radiocarbon date's mean.
- er
The radiocarbon date's lab error.
- cc
calibration curve for the radiocarbon date(s) (see the rintcal package).
- postbomb
Whether or not to use a postbomb curve. Required for negative radiocarbon ages.
- glue
Glue postbomb and prebomb curves together. Defaults to 0 (none), can be 1 (IntCal20 + NH1), 2 (IntCal20 + NH2), 3 (IntCal20 + NH3), 4 (SHCal20 + SH1-2) or 5 (SHCal20 + SH3). Note that this will override the value of cc.
- deltaR
Age offset (e.g. for marine samples). This assumes that the radiocarbon age is provided as 14C BP (not F14C or pMC).
- deltaSTD
Uncertainty of the age offset (1 standard deviation).
- thiscurve
As an alternative to providing cc and/or postbomb, the data of a specific curve can be provided (3 columns: cal BP, C14 age, error).
- cc.dir
Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., cc.dir="curves".
- normal
Use the normal distribution to calibrate dates (default TRUE). The alternative is to use the t model (Christen and Perez 2016).
- as.F
Whether or not to calculate ages in the F14C timescale. Defaults to as.F=FALSE, which uses the C14 timescale.
- is.F
Use this if the provided date is in the F14C timescale.
- t.a
Value a of the t distribution (defaults to 3).
- t.b
Value b of the t distribution (defaults to 4).