Calculate a point estimate of a calibrated distribution - either the weighted mean, the median or the mode (maximum). Note that point estimates often tend to be very poor representations of entire calibrated distributions, so please be careful and do not reduce entire calibrated distributions to just 1 point value.
The calibrated distribution, as returned from caldist(). Alternatively this can be multiple values (e.g., rnorm(1e3, 2450,50)), from which the point estimates will be returned.
wmean
Report the weighted mean (defaults to TRUE)
median
Report the median (defaults to TRUE)
mode
Report the mode, which is the year with the maximum probability (defaults to TRUE)
midpoint
Report the midpoint of the hpd range(s)
prob
probability range for the hpd range(s)
rounded
Rounding for reported probabilities. Defaults to 1 decimal.