rice-package: rice: Radiocarbon Equations

rice-packageR Documentation

rice: Radiocarbon Equations

Description

Provides functions for the calibration of radiocarbon dates, as well as options to calculate different radiocarbon-related timescales (cal BP, cal BC/AD, C14 age, F14C, pMC, D14C) and estimating the effects of contamination or local reservoir offsets (Reimer and Reimer 2001 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/S0033822200038339")}). Supporting publication: Blaauw, M., Reimer, P.J., 2026. An open-source toolkit for radiocarbon dating and calibration. Radiocarbon \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/RDC.2026.10221")}. The methods follow long-established recommendations such as Stuiver and Polach (1977) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/S0033822200003672")} and Reimer et al. (2004) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/S0033822200033154")}. This package uses the calibration curves from the data package 'rintcal'.

Author(s)

Maintainer: Maarten Blaauw maarten.blaauw@qub.ac.uk (ORCID)

Authors:

Other contributors:

See Also

Useful links:


rice documentation built on Aug. 19, 2026, 5:07 p.m.